import pandas as pd
import matplotlib.pyplot as plt
import numpy as np
import sklearn

# Re-export everything under simple names
# Pandas
DataFrame = pd.DataFrame
Series = pd.Series
read_csv = pd.read_csv
read_excel = pd.read_excel

# Numpy
array = np.array
zeros = np.zeros
ones = np.ones
mean = np.mean
std = np.std

# Matplotlib
plot = plt.plot
figure = plt.figure
show = plt.show
scatter = plt.scatter

# Sklearn - you can expose specific modules
from sklearn import linear_model, tree, ensemble, metrics

__version__ = "0.1.0"


from setuptools import setup, find_packages

setup(
    name="npms",
    version="0.1.1",
    author="Toki Tahmid Toufa",
    author_email="toufa6.2832@gmail.com",
    description="A simple Python package that bundles pandas, numpy, matplotlib, and scikit-learn under one unified namespace.",
    long_description=open("README.md").read(),
    long_description_content_type="text/markdown",
    packages=find_packages(),
    install_requires=[
        "pandas",
        "matplotlib",
        "numpy",
        "scikit-learn",
    ],
    python_requires=">=3.8",
)
